
Summary of the package

# Files

Binomialdistribution.py
This file contains python code for calculation mean, stdev, pdf of binomial distribution


Gaussiandistribution.py
This file contains python code for calculation mean, stdev, pdf of Gaussian distribution

Generaldistribution.py
This file contains the layout of distribution